==> zurmo-1.0.20p1.tgz: zurmo/app/protected/core/elements/actions/ListRowActionElement.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * Base class to use for actions that appear in a menu for either list or related list rows.
     */
    abstract class ListRowActionElement extends ActionElement
    {
        public function render()
        {
            return ZurmoHtml::ajaxLink($this->getLabel(), $this->getDefaultRoute(),
                $this->getAjaxLinkOptions(),
                $this->getHtmlOptions()
            );
        }

        protected function getAjaxLinkOptions()
        {
            return array(
            'error'      => 'function(xhr, textStatus, errorThrown) {alert("' .
                            CJavaScript::quote(Yii::t('Default', 'There was an error processing your request')) . '");}',
            'success'    => "js:function(){\$('#" . $this->getLinkId() . "').closest('.items').parent()
                                                        .find('.pager').find('.refresh').find('a').click();}");
        }

        public function renderMenuItem()
        {
            return array('label'           => $this->getLabel(),
                         'url'             => $this->getDefaultRoute(),
                         'linkOptions'     => $this->getHtmlOptions(),
                         'ajaxLinkOptions' => $this->getAjaxLinkOptions()
            );
        }

        protected function getGridId()
        {
            if (!isset($this->params['gridId']))
            {
                throw new NotSupportedException();
            }
            return $this->params['gridId'];
        }

        protected function getModelSingularLabel()
        {
            $modelClassName = $this->params['modelClassName'];
            return $modelClassName::getModelLabelByTypeAndLanguage('SingularLowerCase');
        }
    }
?>

==> zurmo-1.1.31.tgz: zurmo/app/protected/core/elements/actions/ListRowActionElement.php <==
<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    /**
     * Base class to use for actions that appear in a menu for either list or related list rows.
     */
    abstract class ListRowActionElement extends ActionElement
    {
        public function render()
        {
            return ZurmoHtml::ajaxLink($this->getLabel(), $this->getDefaultRoute(),
                $this->getAjaxLinkOptions(),
                $this->getHtmlOptions()
            );
        }

        protected function getAjaxLinkOptions()
        {
            return array(
            'error'      => 'function(xhr, textStatus, errorThrown) {alert("' .
                            CJavaScript::quote(Zurmo::t('Core', 'There was an error processing your request')) . '");}',
            'success'    => "js:function(){\$('#" . $this->getLinkId() . "').closest('.items').parent()
                                                        .find('.pager').find('.refresh').find('a').click();}");
        }

        public function renderMenuItem()
        {
            return array('label'           => $this->getLabel(),
                         'url'             => $this->getDefaultRoute(),
                         'linkOptions'     => $this->getHtmlOptions(),
                         'ajaxLinkOptions' => $this->getAjaxLinkOptions()
            );
        }

        protected function getGridId()
        {
            if (!isset($this->params['gridId']))
            {
                throw new NotSupportedException();
            }
            return $this->params['gridId'];
        }

        protected function getModelSingularLabel()
        {
            $modelClassName = $this->params['modelClassName'];
            return $modelClassName::getModelLabelByTypeAndLanguage('SingularLowerCase');
        }
    }
?>
